==> jxl-cli-0.0.3.tgz: package/src/scripts/create.ts <==
import { prompt } from 'inquirer';
import * as ora from 'ora';
import * as fse from 'fs-extra';

import { download } from '../utils/download';
import { CliQuestions } from '../config/question';
import { logColor, logSymbol } from '../utils/log';
import { runCommand } from '../utils/tool';

const create = async (projectName, key, value) => {
  if (!projectName) {
    console.log('Please specify the project directory:');
    logColor(' jxl create', 'blue', ' <project-directory>', 'green');
    console.log('\n');
    console.log('For example:');
    logColor(' jxl create', 'blue', ' my-app', 'green');
    process.exit(1);

  } else if (fse.existsSync(projectName)) {

    logSymbol('The project already exists.', 'error');
    
  } else {
    const { template, description, author, isInstall } = await prompt(CliQuestions);

    const spinner = ora();
    spinner.start('🚀 Start downloading template code ...');

    download(template, projectName)
      .then(() => {

        const fileName = `${projectName}/package.json`;

        if (fse.existsSync(fileName)) {
          const data = fse.readFileSync(fileName).toString();
          let json = JSON.parse(data);
          json.name = projectName;
          json.description = description;
          json.author = author;

          fse.writeFileSync(fileName, JSON.stringify(json, null, '\t'), 'utf-8');

          spinner.succeed('🎉 Download successfully.\n');
          spinner.stop();
        }

        (async () => {
          if (isInstall) {
            try {
              logColor('🚀 Start installing dependencies', 'blue');
              await runCommand(`cd ${projectName} && yarn install`);
              logSymbol(`🎉 Installation successfully.\n`, 'success');
              
              logColor('😄 Coding now.', 'blue');
              logColor('         cd', 'blue', `${projectName}`, 'green');
              logColor('         yarn', 'blue', 'start', 'green');

            } catch (err) {
              logSymbol(`❌ Installation failed. ${err}`, 'error');
              process.exit(1);
            }
          }
        })();
        
      })
      .catch(err => {
        spinner.fail(`❌ The project created fail. ${err}`);
      })
  }
};

module.exports = create;

==> jxl-cli-0.0.5.tgz: package/src/scripts/create.ts <==
import { prompt } from 'inquirer';
import * as ora from 'ora';
import * as fse from 'fs-extra';

import { download } from '../utils/download';
import { CliQuestions } from '../config/question';
import { logColor, logSymbol } from '../utils/log';
import { runCommand } from '../utils/tool';
import { getPkgTool } from '../utils/npm';

const create = async (projectName, key, value) => {

  if (!projectName) {
    console.log('Please specify the project directory:');
    logColor(' jxl create', 'blue', ' <project-directory>', 'green');
    console.log('\n');
    console.log('For example:');
    logColor(' jxl create', 'blue', ' my-app', 'green');
    process.exit(1);

  } else if (fse.existsSync(projectName)) {
    logSymbol('😅 The project already exists.', 'error');
    process.exit(1);
  } else {
    const { template, description, author, isInstall } = await prompt(CliQuestions);

    const spinner = ora();
    spinner.start('🚀 Start downloading template code ...');

    download(template, projectName)
      .then(() => {

        const fileName = `${projectName}/package.json`;

        if (fse.existsSync(fileName)) {
          const data = fse.readFileSync(fileName).toString();
          let json = JSON.parse(data);
          json.name = projectName;
          json.description = description;
          json.author = author;

          fse.writeFileSync(fileName, JSON.stringify(json, null, '\t'), 'utf-8');

          spinner.succeed('🎉 Download successfully.\n');
          spinner.stop();
        }

        (async () => {
          const pkgTool = getPkgTool(projectName);
          if (isInstall) {
            try {
              logColor('🚀 Start installing dependencies', 'blue');
              await runCommand(`cd ${projectName} && ${pkgTool} install`);
              logSymbol(`🎉 Installation successfully.\n`, 'success');

              logColor('[INFO] Coding now...', 'blue');
              logColor('         cd', 'blue', `${projectName}\r\n`, 'green');
              logColor(`         ${pkgTool}`, 'blue', 'start\r\n', 'green');

            } catch (err) {
              logSymbol(`❌ Installation failed. ${err}`, 'error');
              process.exit(1);
            }
          } else {
            logColor('[INFO] Coding now...\r\n', 'blue');
            logColor('        cd', 'blue', `${projectName}\r\n`, 'green');
            logColor(`        ${pkgTool}`, 'blue', `install\r\n`, 'green');
            logColor(`        ${pkgTool}`, 'blue', 'start\r\n', 'green');
          }
        })();

      })
      .catch(err => {
        spinner.fail(`❌ The project created fail. ${err}`);
      })
  }


};

module.exports = create;
